summaryrefslogtreecommitdiffstats
path: root/cc/output/software_output_device.h
diff options
context:
space:
mode:
authorreed@google.com <reed@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-25 03:29:30 +0000
committerreed@google.com <reed@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-25 03:29:30 +0000
commit55af09e5315808c31b9a915d79395ab3edcfee45 (patch)
treeb7ccaffadf3d326b1b5fcd642d149338f33e5c1b /cc/output/software_output_device.h
parentd3e172f206dabce5adfd7249b2f1a6b6c5ed8713 (diff)
downloadchromium_src-55af09e5315808c31b9a915d79395ab3edcfee45.zip
chromium_src-55af09e5315808c31b9a915d79395ab3edcfee45.tar.gz
chromium_src-55af09e5315808c31b9a915d79395ab3edcfee45.tar.bz2
change SoftwareOutputDevice CopyToBitmap to CopyToPixels, and remove device_ member variable
- SkDevice is deprecated - unneeded with cleaner SkCanvas::readPixels() signature Review URL: https://codereview.chromium.org/197703006 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@259125 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'cc/output/software_output_device.h')
-rw-r--r--cc/output/software_output_device.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/cc/output/software_output_device.h b/cc/output/software_output_device.h
index f03e964..e371654 100644
--- a/cc/output/software_output_device.h
+++ b/cc/output/software_output_device.h
@@ -50,8 +50,8 @@ class CC_EXPORT SoftwareOutputDevice {
virtual void EndPaint(SoftwareFrameData* frame_data);
// Copies pixels inside |rect| from the current software framebuffer to
- // |output|. Fails if there is no current softwareframebuffer.
- virtual void CopyToBitmap(const gfx::Rect& rect, SkBitmap* output);
+ // |pixels|. Fails if there is no current softwareframebuffer.
+ virtual void CopyToPixels(const gfx::Rect& rect, void* pixels);
// Blit the pixel content of the SoftwareOutputDevice by |delta| with the
// write clipped to |clip_rect|.
@@ -76,7 +76,6 @@ class CC_EXPORT SoftwareOutputDevice {
protected:
gfx::Size viewport_size_;
gfx::Rect damage_rect_;
- skia::RefPtr<SkBaseDevice> device_;
skia::RefPtr<SkCanvas> canvas_;
scoped_ptr<gfx::VSyncProvider> vsync_provider_;